==> as-service-api-0.0.1-20150715.133925-5-sources.jar: com/xdja/cssp/as/service/model/ClientLoginReq.java <==
package com.xdja.cssp.as.service.model;

import java.io.Serializable;

/**
 * 客户端登录请求Bean
 * @author wyf
 *
 */
public class ClientLoginReq implements Serializable {

	private static final long serialVersionUID = 1L;
	
	/**
	 * 客户端类型；1-Andorid，2-IOS；3-PC，4-其他
	 */
	private Integer clientType;
	/**
	 * 登录类型；1-芯片登录，2-TF卡登录，3-USBKey
	 */
	private Integer loginType;
	/**
	 * 客户端型号
	 */
	private String clientModel;
	/**
	 * 客户端操作系统名称
	 */
	private String osName;
	/**
	 * 客户端操作系统版本号
	 */
	private String osVersion;
	/**
	 * 客户端唯一标识，必须能鉴别出终端
	 */
	private String resource;
	/**
	 * 推送标识
	 */
	private String pnToken; 
	/**
	 * 终端芯片卡号
	 */
	private String cardNo;
	/**
	 * 终端签名证书SN
	 */
	private String sn;
	/**
	 * 终端证书算法 1-RSA;2-SM2
	 */
	private int caAlg;

	public Integer getClientType() {
		return clientType;
	}

	public void setClientType(Integer clientType) {
		this.clientType = clientType;
	}

	public Integer getLoginType() {
		return loginType;
	}

	public void setLoginType(Integer loginType) {
		this.loginType = loginType;
	}

	public String getClientModel() {
		return clientModel;
	}

	public void setClientModel(String clientModel) {
		this.clientModel = clientModel;
	}

	public String getOsName() {
		return osName;
	}

	public void setOsName(String osName) {
		this.osName = osName;
	}

	public String getOsVersion() {
		return osVersion;
	}

	public void setOsVersion(String osVersion) {
		this.osVersion = osVersion;
	}

	public String getResource() {
		return resource;
	}

	public void setResource(String resource) {
		this.resource = resource;
	}

	public String getPnToken() {
		return pnToken;
	}

	public void setPnToken(String pnToken) {
		this.pnToken = pnToken;
	}

	public String getCardNo() {
		return cardNo;
	}

	public void setCardNo(String cardNo) {
		this.cardNo = cardNo;
	}

	public String getSn() {
		return sn;
	}

	public void setSn(String sn) {
		this.sn = sn;
	}

	public int getCaAlg() {
		return caAlg;
	}

	public void setCaAlg(int caAlg) {
		this.caAlg = caAlg;
	}

}

==> as-service-api-0.0.1-20151019.090129-13-sources.jar: com/xdja/cssp/as/service/model/ClientLoginReq.java <==
package com.xdja.cssp.as.service.model;

import java.io.Serializable;

/**
 * 客户端登录请求Bean
 * @author wyf
 *
 */
public class ClientLoginReq implements Serializable {

	private static final long serialVersionUID = 1L;
	
	/**
	 * 客户端类型；1-Andorid，2-IOS；3-PC，4-其他
	 */
	private Integer clientType;
	/**
	 * 登录类型；1-芯片登录，2-TF卡登录，3-USBKey
	 */
	private Integer loginType;
	/**
	 * 客户端型号
	 */
	private String clientModel;
	/**
	 * 客户端操作系统名称
	 */
	private String osName;
	/**
	 * 客户端操作系统版本号
	 */
	private String osVersion;
	/**
	 * 安通+客户端版本号
	 */
	private String clientVersion;
	/**
	 * 客户端唯一标识，必须能鉴别出终端
	 */
	private String resource;
	/**
	 * 推送标识
	 */
	private String pnToken; 
	/**
	 * 终端芯片卡号
	 */
	private String cardNo;
	/**
	 * 终端签名证书SN
	 */
	private String sn;
	/**
	 * 终端证书算法 1-RSA;2-SM2
	 */
	private int caAlg;

	public Integer getClientType() {
		return clientType;
	}

	public void setClientType(Integer clientType) {
		this.clientType = clientType;
	}

	public Integer getLoginType() {
		return loginType;
	}

	public void setLoginType(Integer loginType) {
		this.loginType = loginType;
	}

	public String getClientModel() {
		return clientModel;
	}

	public void setClientModel(String clientModel) {
		this.clientModel = clientModel;
	}

	public String getOsName() {
		return osName;
	}

	public void setOsName(String osName) {
		this.osName = osName;
	}

	public String getOsVersion() {
		return osVersion;
	}

	public void setOsVersion(String osVersion) {
		this.osVersion = osVersion;
	}

	public String getClientVersion() {
		return clientVersion;
	}

	public void setClientVersion(String clientVersion) {
		this.clientVersion = clientVersion;
	}

	public String getResource() {
		return resource;
	}

	public void setResource(String resource) {
		this.resource = resource;
	}

	public String getPnToken() {
		return pnToken;
	}

	public void setPnToken(String pnToken) {
		this.pnToken = pnToken;
	}

	public String getCardNo() {
		return cardNo;
	}

	public void setCardNo(String cardNo) {
		this.cardNo = cardNo;
	}

	public String getSn() {
		return sn;
	}

	public void setSn(String sn) {
		this.sn = sn;
	}

	public int getCaAlg() {
		return caAlg;
	}

	public void setCaAlg(int caAlg) {
		this.caAlg = caAlg;
	}

}
